#!/usr/bin/env python

"""
Acorn Electron ULA simulation controller.
"""

from ula import *
import pygame

WIDTH = 640
HEIGHT = 512
INTENSITY = 255

def update_screen(screen, screen_array):

    """
    Update the host's 'screen' surface with the contents of the 'screen_array'
    containing the pixel content of the screen.
    """

    surface = pygame.Surface((MAX_WIDTH, MAX_HEIGHT), 0, screen)
    sa = pygame.surfarray.pixels3d(surface)
    a = sa.transpose(1, 0, 2)

    # Copy the array to a surface and apply a pixel intensity.

    try:
        a[:] = screen_array
        a *= INTENSITY
    finally:
        del a, sa

    # Scale the surface to the dimensions of the host's screen and copy the
    # result to the host's screen.

    screen.blit(pygame.transform.scale(surface, (WIDTH, HEIGHT)), (0, 0))

def mainloop():
    while 1:
        pygame.display.flip()
        event = pygame.event.wait()
        if event.type == pygame.KEYDOWN and event.key == pygame.K_ESCAPE:
            break

if __name__ == "__main__":
    pygame.init()
    screen = pygame.display.set_mode((WIDTH, HEIGHT), 0)

    ula = get_ula()

    # Test MODE 2.

    ula.set_mode(2)

    ula.fill(0x3000, 0x5800 - 320, encode((1, 6), 4))
    ula.fill(0x5800 - 320, 0x8000, encode((2, 7), 4))
    ula_screen = update(ula)
    update_screen(screen, ula_screen)
    mainloop()

    ula.screen_start = 0x3000 + 2
    ula_screen = update(ula)
    update_screen(screen, ula_screen)
    mainloop()

    # Test MODE 6.

    ula.set_mode(6)

    ula.fill(0x6000, 0x6f00 + 160, encode((1, 0, 1, 1, 0, 0, 1, 1), 1))
    ula.fill(0x6f00 + 160, 0x7f40, encode((1, 0, 1, 0, 1, 0, 1, 0), 1))
    ula_screen = update(ula)
    update_screen(screen, ula_screen)
    mainloop()

    ula.screen_start = 0x6f00 + 160
    ula_screen = update(ula)
    update_screen(screen, ula_screen)
    mainloop()

# vim: tabstop=4 expandtab shiftwidth=4
